#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyramid.decorator import reify
from pyramid.exceptions import HTTPForbidden

from pyams_content.features.alert import IAlertItem
from pyams_content.features.alert.interfaces import IAlertTarget
from pyams_content.features.alert.zmi import AlertContainerView, \
    AlertItemAddAction as AlertItemAddActionBase, \
    AlertItemAddForm as AlertItemAddFormBase, \
    AlertItemPropertiesEditForm as AlertItemPropertiesEditFormBase
from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION, MANAGE_SITE_ROOT_PERMISSION
from pyams_content.shared.common import IWfSharedContent
from pyams_form.form import AJAXAddForm, ajax_config
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces.viewlet import IWidgetTitleViewletManager
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import viewlet_config


def check_alert_view(request):
    """Check alerts views"""
    content = get_parent(request.context, IWfSharedContent)
    if content is None:
        permission = MANAGE_SITE_ROOT_PERMISSION
    else:
        permission = MANAGE_CONTENT_PERMISSION
    if not request.has_permission(permission):
        raise HTTPForbidden()


class AlertPermissionMixin:
    """Custom alerts permisison mixin"""

    @reify
    def permission(self):
        if IWfSharedContent.providedBy(self.context):
            return MANAGE_CONTENT_PERMISSION
        return MANAGE_SITE_ROOT_PERMISSION

    @reify
    def edit_permission(self):
        content = get_parent(self.context, IWfSharedContent)
        if content is not None:
            return MANAGE_CONTENT_PERMISSION
        return MANAGE_SITE_ROOT_PERMISSION


@viewlet_config(name='add-alert.action',
                context=IAlertTarget, layer=IPyAMSLayer,
                view=AlertContainerView, manager=IWidgetTitleViewletManager,
                weight=1)
class AlertItemAddAction(AlertPermissionMixin, AlertItemAddActionBase):
    """Alert item add action"""


@pagelet_config(name='add-alert.html',
                context=IAlertTarget, layer=IPyAMSLayer)
@ajax_config(name='add-alert.json',
             context=IAlertTarget, layer=IPyAMSLayer, base=AJAXAddForm)
class AlertItemAddForm(AlertPermissionMixin, AlertItemAddFormBase):
    """Alert item add form"""


@pagelet_config(name='properties.html',
                context=IAlertItem, layer=IPyAMSLayer)
@ajax_config(name='properties.json', context=IAlertItem, layer=IPyAMSLayer)
class AlertItemPropertiesEditForm(AlertPermissionMixin, AlertItemPropertiesEditFormBase):
    """Alert item properties edit form"""
